.. _integrations:

Integrations
------------

.. _aiobotocore:

aiobotocore
^^^^^^^^^^^
.. automodule:: ddtrace.contrib.aiobotocore


.. _aiopg:

aiopg
^^^^^
.. automodule:: ddtrace.contrib.aiopg


.. _algoliasearch:

algoliasearch
^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.algoliasearch


.. _asgi:

asgi
^^^^
.. automodule:: ddtrace.contrib.asgi


.. _aiohttp:

aiohttp
^^^^^^^
.. automodule:: ddtrace.contrib.aiohttp


.. _asyncio:

asyncio
^^^^^^^
.. automodule:: ddtrace.contrib.asyncio


.. _botocore:

botocore
^^^^^^^^
.. automodule:: ddtrace.contrib.botocore


.. _boto2:

boto2
^^^^^
.. automodule:: ddtrace.contrib.boto


.. _bottle:

Bottle
^^^^^^
.. automodule:: ddtrace.contrib.bottle


.. _cassandra:

Cassandra
^^^^^^^^^
.. automodule:: ddtrace.contrib.cassandra


.. _celery:

Celery
^^^^^^
.. automodule:: ddtrace.contrib.celery


.. _cherrypy:

CherryPy
^^^^^^^^
.. automodule:: ddtrace.contrib.cherrypy


.. _consul:

Consul
^^^^^^
.. automodule:: ddtrace.contrib.consul


.. _djangorestframework:
.. _django:

Django
^^^^^^
.. automodule:: ddtrace.contrib.django


.. _dogpile.cache:

dogpile.cache
^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.dogpile_cache


.. _elasticsearch:

Elasticsearch
^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.elasticsearch


.. _falcon:

Falcon
^^^^^^
.. automodule:: ddtrace.contrib.falcon


.. _fastapi:

Fastapi
^^^^^^^^^
.. automodule:: ddtrace.contrib.fastapi


.. _flask:

Flask
^^^^^
.. automodule:: ddtrace.contrib.flask


.. _flask_cache:

Flask Cache
^^^^^^^^^^^
.. automodule:: ddtrace.contrib.flask_cache


.. _futures:

futures
^^^^^^^
.. automodule:: ddtrace.contrib.futures


.. _gevent:

gevent
^^^^^^
.. automodule:: ddtrace.contrib.gevent


.. _grpc:

Grpc
^^^^
.. automodule:: ddtrace.contrib.grpc


.. _httplib:

httplib
^^^^^^^
.. automodule:: ddtrace.contrib.httplib

.. _httpx:

httpx
^^^^^
.. automodule:: ddtrace.contrib.httpx


.. _jinja2:

Jinja2
^^^^^^
.. automodule:: ddtrace.contrib.jinja2


.. _kombu:

kombu
^^^^^
.. automodule:: ddtrace.contrib.kombu


.. _mako:

Mako
^^^^
.. automodule:: ddtrace.contrib.mako


.. _mariadb:

MariaDB
^^^^^^^
.. automodule:: ddtrace.contrib.mariadb


.. _molten:

Molten
^^^^^^
.. automodule:: ddtrace.contrib.molten


.. _mongoengine:

Mongoengine
^^^^^^^^^^^
.. automodule:: ddtrace.contrib.mongoengine


.. _mysql-connector:

mysql-connector
^^^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.mysql


.. _mysqlclient:
.. _mysqldb:

mysqlclient
^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.mysqldb


.. _pylibmc:

pylibmc
^^^^^^^
.. automodule:: ddtrace.contrib.pylibmc


.. _pylons:

Pylons
^^^^^^
.. automodule:: ddtrace.contrib.pylons


.. _pynamodb:

PynamoDB
^^^^^^^^
.. automodule:: ddtrace.contrib.pynamodb


.. _pyodbc:

PyODBC
^^^^^^^^
.. automodule:: ddtrace.contrib.pyodbc


.. _pymemcache:

pymemcache
^^^^^^^^^^
.. automodule:: ddtrace.contrib.pymemcache


.. _pymongo:

Pymongo
^^^^^^^
.. automodule:: ddtrace.contrib.pymongo


.. _pymysql:

pymysql
^^^^^^^
.. automodule:: ddtrace.contrib.pymysql


.. _pyramid:

Pyramid
^^^^^^^
.. automodule:: ddtrace.contrib.pyramid


.. _pytest:

pytest
^^^^^^
.. automodule:: ddtrace.contrib.pytest


.. _psycopg2:

psycopg
^^^^^^^
.. automodule:: ddtrace.contrib.psycopg


.. _redis:

redis
^^^^^
.. automodule:: ddtrace.contrib.redis


.. _rediscluster:

redis-py-cluster
^^^^^^^^^^^^^^^^
.. automodule:: ddtrace.contrib.rediscluster


.. _requests:

Requests
^^^^^^^^
.. automodule:: ddtrace.contrib.requests


.. _sanic:

Sanic
^^^^^
.. automodule:: ddtrace.contrib.sanic


.. _starlette:

Starlette
^^^^^^^^^
.. automodule:: ddtrace.contrib.starlette


.. _sqlalchemy:

SQLAlchemy
^^^^^^^^^^
.. automodule:: ddtrace.contrib.sqlalchemy


.. _sqllite:

SQLite
^^^^^^
.. automodule:: ddtrace.contrib.sqlite3


.. _tornado:

Tornado
^^^^^^^
.. automodule:: ddtrace.contrib.tornado


.. _urllib3:

urllib3
^^^^^^^
.. automodule:: ddtrace.contrib.urllib3


.. _vertica:

Vertica
^^^^^^^
.. automodule:: ddtrace.contrib.vertica


.. _wsgi:

WSGI
^^^^
.. automodule:: ddtrace.contrib.wsgi
